/*
 * Copyright 2008 Adam Tacy <adam.tacy AT gmail.com>
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.adamtacy.client.ui.effects.core;

import org.adamtacy.client.ui.effects.NEffect;


/**
 * 
 * Creates a change color effect for an Effect Panel. Colour will "morph" from a
 * start-colour to an end-colour By default the background style attribute is
 * used, but this can be altered by using the additional constructor
 * ChangeColour(styleElementName)
 * 
 * At the end of the effect, the original background colour of the component is
 * restored.
 * 
 */
public class NMorphColor extends NEffect {
  
  public void setPosition(double progress){
    double val = interpolate(progress);
    this.onUpdate(val);
}
  
  /**
   * Change the start color to either a hex value or a rgb(r,g,b) value Both
   * contained within the input string
   * 
   * @param styleSheetColor
   */
  public void setEndColor(String styleSheetEndColor) {
    colourStyleImpl.setEndColor(styleSheetEndColor);
    if ((thePanel!=null) && thePanel.isAttached()) setUpEffect();
  }
  
  public String getEndColor(){
    return colourStyleImpl.getEndColour();
  }
  
  public String getStartColor(){
    return colourStyleImpl.getStartColour();
  }
  

  /**
   * Change the start color to either a hex value or a rgb(r,g,b) value Both
   * contained within the input string
   * 
   * @param styleSheetColor
   */
  public void setStartColor(String styleSheetStartColor) {
    colourStyleImpl.setStartColor(styleSheetStartColor);
    if ((thePanel!=null) && thePanel.isAttached()) setUpEffect();
  }

  
  /**
   * 
   * Inner class that allows user to set properties of Effect.
   * @deprecated
   */
  public class ColourProperties extends BaseProperties {
    /**
     * Change the start color to either a hex value or a rgb(r,g,b) value Both
     * contained within the input string
     * 
     * @param styleSheetColor
     * @deprecated
     */
    public void setEndColor(String styleSheetEndColor) {
      colourStyleImpl.setEndColor(styleSheetEndColor);
      if (thePanel != null)
        if (thePanel.isAttached())
          setUpEffect();
    }

    /**
     * Change the start color to either a hex value or a rgb(r,g,b) value Both
     * contained within the input string
     * 
     * @param styleSheetColor
     * @deprecated
     */
    public void setStartColor(String styleSheetStartColor) {
      colourStyleImpl.setStartColor(styleSheetStartColor);
      if (thePanel != null)
        if (thePanel.isAttached())
          setUpEffect();
    }
  }


  NChangeColorAction colourStyleImpl = new NChangeColorAction();

  protected String styleComponentToChange = "";

  /**
   * Internal copy of the properties object
   * @deprecated
   */
  private ColourProperties theColourProperties = new ColourProperties();

  public NMorphColor(String styleName) {
    super();
    styleComponentToChange = styleName;
  }

  public NMorphColor(String styleName, String styleStart, String styleEnd) {
    this(styleName);
    if (!styleStart.equals("")) {
      setStartColor(styleStart);
    }
    setEndColor(styleEnd);
  }

  /**
   * Allow the user to retrieve a copy of the properties object.
   * 
   * @return ColourProperties object
   * @deprecated
   */
  public ColourProperties getProperties() {
    return theColourProperties;
  }

  @Override
  protected void onUpdate(double progress) {
    super.onUpdate(progress);
    colourStyleImpl.performStep(effectElement, styleComponentToChange, progress);
  }

  @Override
  protected void setUpEffect() {
    effectElement = thePanel.getPanelWidget().getElement();
    colourStyleImpl.setUp(effectElement, styleComponentToChange, 0);
  }

  @Override
  public void tearDownEffect() {
    colourStyleImpl.tearDownEffect(effectElement);
  }
}